@@ -39,8 +39,8 @@ def lexs_of(sentence):
 
 def to_json(infile,outfile):
   client = NLPclient()
-  with open(infile,'r') as f : text=f.read()
-  with open(outfile, 'w') as g:
+  with ropen(infile) as f : text=f.read()
+  with wopen(outfile) as g:
     xs=[x for x in client.extract(text)]
     json.dump(xs,g,indent=2)
 
@@ -86,6 +86,6 @@ class NLPclient:
 
 def show_extract(infile):
   client = NLPclient()
-  with open(infile,'r') as f : text=f.read()
+  with ropen(infile) as f : text=f.read()
   for x in client.extract(text) :
     print(x)
